@@ -1,19 +1,21 @@
 """
-Main interface for codebuild service type definitions.
+Type annotations for codebuild service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_codebuild.type_defs import BatchRestrictionsTypeDef
+    from mypy_boto3_codebuild.type_defs import BatchDeleteBuildsOutputTypeDef
 
-    data: BatchRestrictionsTypeDef = {...}
+    data: BatchDeleteBuildsOutputTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-from mypy_boto3_codebuild.literals import (
+from .literals import (
     ArtifactNamespace,
     ArtifactPackaging,
     ArtifactsType,
@@ -24,10 +26,8 @@ from mypy_boto3_codebuild.literals import (
     CacheMode,
     CacheType,
     ComputeType,
-    CredentialProviderType,
     EnvironmentType,
     EnvironmentVariableType,
-    FileSystemType,
     ImagePullCredentialsType,
     LanguageType,
     LogsConfigStatusType,
@@ -38,13 +38,16 @@ from mypy_boto3_codebuild.literals import (
     ReportStatusType,
     ReportType,
     ServerType,
-    SourceAuthType,
     SourceType,
     StatusType,
     WebhookBuildType,
     WebhookFilterType,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -52,8 +55,15 @@ else:
 
 
 __all__ = (
+    "BatchDeleteBuildsOutputTypeDef",
+    "BatchGetBuildBatchesOutputTypeDef",
+    "BatchGetBuildsOutputTypeDef",
+    "BatchGetProjectsOutputTypeDef",
+    "BatchGetReportGroupsOutputTypeDef",
+    "BatchGetReportsOutputTypeDef",
     "BatchRestrictionsTypeDef",
     "BuildArtifactsTypeDef",
+    "BuildBatchFilterTypeDef",
     "BuildBatchPhaseTypeDef",
     "BuildBatchTypeDef",
     "BuildGroupTypeDef",
@@ -65,60 +75,22 @@ __all__ = (
     "CloudWatchLogsConfigTypeDef",
     "CodeCoverageReportSummaryTypeDef",
     "CodeCoverageTypeDef",
+    "CreateProjectOutputTypeDef",
+    "CreateReportGroupOutputTypeDef",
+    "CreateWebhookOutputTypeDef",
     "DebugSessionTypeDef",
+    "DeleteBuildBatchOutputTypeDef",
+    "DeleteSourceCredentialsOutputTypeDef",
+    "DescribeCodeCoveragesOutputTypeDef",
+    "DescribeTestCasesOutputTypeDef",
     "EnvironmentImageTypeDef",
     "EnvironmentLanguageTypeDef",
     "EnvironmentPlatformTypeDef",
     "EnvironmentVariableTypeDef",
     "ExportedEnvironmentVariableTypeDef",
-    "GitSubmodulesConfigTypeDef",
-    "LogsConfigTypeDef",
-    "LogsLocationTypeDef",
-    "NetworkInterfaceTypeDef",
-    "PhaseContextTypeDef",
-    "ProjectArtifactsTypeDef",
-    "ProjectBadgeTypeDef",
-    "ProjectBuildBatchConfigTypeDef",
-    "ProjectCacheTypeDef",
-    "ProjectEnvironmentTypeDef",
-    "ProjectFileSystemLocationTypeDef",
-    "ProjectSourceTypeDef",
-    "ProjectSourceVersionTypeDef",
-    "ProjectTypeDef",
-    "RegistryCredentialTypeDef",
-    "ReportExportConfigTypeDef",
-    "ReportGroupTrendStatsTypeDef",
-    "ReportGroupTypeDef",
-    "ReportTypeDef",
-    "ReportWithRawDataTypeDef",
-    "ResolvedArtifactTypeDef",
-    "ResponseMetadata",
-    "S3LogsConfigTypeDef",
-    "S3ReportExportConfigTypeDef",
-    "SourceAuthTypeDef",
-    "SourceCredentialsInfoTypeDef",
-    "TagTypeDef",
-    "TestCaseTypeDef",
-    "TestReportSummaryTypeDef",
-    "VpcConfigTypeDef",
-    "WebhookFilterTypeDef",
-    "WebhookTypeDef",
-    "BatchDeleteBuildsOutputTypeDef",
-    "BatchGetBuildBatchesOutputTypeDef",
-    "BatchGetBuildsOutputTypeDef",
-    "BatchGetProjectsOutputTypeDef",
-    "BatchGetReportGroupsOutputTypeDef",
-    "BatchGetReportsOutputTypeDef",
-    "BuildBatchFilterTypeDef",
-    "CreateProjectOutputTypeDef",
-    "CreateReportGroupOutputTypeDef",
-    "CreateWebhookOutputTypeDef",
-    "DeleteBuildBatchOutputTypeDef",
-    "DeleteSourceCredentialsOutputTypeDef",
-    "DescribeCodeCoveragesOutputTypeDef",
-    "DescribeTestCasesOutputTypeDef",
     "GetReportGroupTrendOutputTypeDef",
     "GetResourcePolicyOutputTypeDef",
+    "GitSubmodulesConfigTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
     "ListBuildBatchesForProjectOutputTypeDef",
     "ListBuildBatchesOutputTypeDef",
@@ -132,24 +104,112 @@ __all__ = (
     "ListSharedProjectsOutputTypeDef",
     "ListSharedReportGroupsOutputTypeDef",
     "ListSourceCredentialsOutputTypeDef",
+    "LogsConfigTypeDef",
+    "LogsLocationTypeDef",
+    "NetworkInterfaceTypeDef",
     "PaginatorConfigTypeDef",
+    "PhaseContextTypeDef",
+    "ProjectArtifactsTypeDef",
+    "ProjectBadgeTypeDef",
+    "ProjectBuildBatchConfigTypeDef",
+    "ProjectCacheTypeDef",
+    "ProjectEnvironmentTypeDef",
+    "ProjectFileSystemLocationTypeDef",
+    "ProjectSourceTypeDef",
+    "ProjectSourceVersionTypeDef",
+    "ProjectTypeDef",
     "PutResourcePolicyOutputTypeDef",
+    "RegistryCredentialTypeDef",
+    "ReportExportConfigTypeDef",
     "ReportFilterTypeDef",
+    "ReportGroupTrendStatsTypeDef",
+    "ReportGroupTypeDef",
+    "ReportTypeDef",
+    "ReportWithRawDataTypeDef",
+    "ResolvedArtifactTypeDef",
+    "ResponseMetadataTypeDef",
     "RetryBuildBatchOutputTypeDef",
     "RetryBuildOutputTypeDef",
+    "S3LogsConfigTypeDef",
+    "S3ReportExportConfigTypeDef",
+    "SourceAuthTypeDef",
+    "SourceCredentialsInfoTypeDef",
     "StartBuildBatchOutputTypeDef",
     "StartBuildOutputTypeDef",
     "StopBuildBatchOutputTypeDef",
     "StopBuildOutputTypeDef",
+    "TagTypeDef",
     "TestCaseFilterTypeDef",
+    "TestCaseTypeDef",
+    "TestReportSummaryTypeDef",
     "UpdateProjectOutputTypeDef",
     "UpdateReportGroupOutputTypeDef",
     "UpdateWebhookOutputTypeDef",
+    "VpcConfigTypeDef",
+    "WebhookFilterTypeDef",
+    "WebhookTypeDef",
+)
+
+BatchDeleteBuildsOutputTypeDef = TypedDict(
+    "BatchDeleteBuildsOutputTypeDef",
+    {
+        "buildsDeleted": List[str],
+        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetBuildBatchesOutputTypeDef = TypedDict(
+    "BatchGetBuildBatchesOutputTypeDef",
+    {
+        "buildBatches": List["BuildBatchTypeDef"],
+        "buildBatchesNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetBuildsOutputTypeDef = TypedDict(
+    "BatchGetBuildsOutputTypeDef",
+    {
+        "builds": List["BuildTypeDef"],
+        "buildsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetProjectsOutputTypeDef = TypedDict(
+    "BatchGetProjectsOutputTypeDef",
+    {
+        "projects": List["ProjectTypeDef"],
+        "projectsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetReportGroupsOutputTypeDef = TypedDict(
+    "BatchGetReportGroupsOutputTypeDef",
+    {
+        "reportGroups": List["ReportGroupTypeDef"],
+        "reportGroupsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetReportsOutputTypeDef = TypedDict(
+    "BatchGetReportsOutputTypeDef",
+    {
+        "reports": List["ReportTypeDef"],
+        "reportsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
 )
 
 BatchRestrictionsTypeDef = TypedDict(
     "BatchRestrictionsTypeDef",
-    {"maximumBuildsAllowed": int, "computeTypesAllowed": List[str]},
+    {
+        "maximumBuildsAllowed": int,
+        "computeTypesAllowed": List[str],
+    },
     total=False,
 )
 
@@ -167,6 +227,14 @@ BuildArtifactsTypeDef = TypedDict(
     total=False,
 )
 
+BuildBatchFilterTypeDef = TypedDict(
+    "BuildBatchFilterTypeDef",
+    {
+        "status": StatusType,
+    },
+    total=False,
+)
+
 BuildBatchPhaseTypeDef = TypedDict(
     "BuildBatchPhaseTypeDef",
     {
@@ -230,7 +298,12 @@ BuildGroupTypeDef = TypedDict(
 )
 
 BuildNotDeletedTypeDef = TypedDict(
-    "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
+    "BuildNotDeletedTypeDef",
+    {
+        "id": str,
+        "statusCode": str,
+    },
+    total=False,
 )
 
 BuildPhaseTypeDef = TypedDict(
@@ -247,7 +320,12 @@ BuildPhaseTypeDef = TypedDict(
 )
 
 BuildStatusConfigTypeDef = TypedDict(
-    "BuildStatusConfigTypeDef", {"context": str, "targetUrl": str}, total=False
+    "BuildStatusConfigTypeDef",
+    {
+        "context": str,
+        "targetUrl": str,
+    },
+    total=False,
 )
 
 BuildSummaryTypeDef = TypedDict(
@@ -302,10 +380,18 @@ BuildTypeDef = TypedDict(
 )
 
 _RequiredCloudWatchLogsConfigTypeDef = TypedDict(
-    "_RequiredCloudWatchLogsConfigTypeDef", {"status": LogsConfigStatusType}
+    "_RequiredCloudWatchLogsConfigTypeDef",
+    {
+        "status": LogsConfigStatusType,
+    },
 )
 _OptionalCloudWatchLogsConfigTypeDef = TypedDict(
-    "_OptionalCloudWatchLogsConfigTypeDef", {"groupName": str, "streamName": str}, total=False
+    "_OptionalCloudWatchLogsConfigTypeDef",
+    {
+        "groupName": str,
+        "streamName": str,
+    },
+    total=False,
 )
 
 
@@ -345,31 +431,116 @@ CodeCoverageTypeDef = TypedDict(
     total=False,
 )
 
+CreateProjectOutputTypeDef = TypedDict(
+    "CreateProjectOutputTypeDef",
+    {
+        "project": "ProjectTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateReportGroupOutputTypeDef = TypedDict(
+    "CreateReportGroupOutputTypeDef",
+    {
+        "reportGroup": "ReportGroupTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateWebhookOutputTypeDef = TypedDict(
+    "CreateWebhookOutputTypeDef",
+    {
+        "webhook": "WebhookTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DebugSessionTypeDef = TypedDict(
-    "DebugSessionTypeDef", {"sessionEnabled": bool, "sessionTarget": str}, total=False
+    "DebugSessionTypeDef",
+    {
+        "sessionEnabled": bool,
+        "sessionTarget": str,
+    },
+    total=False,
+)
+
+DeleteBuildBatchOutputTypeDef = TypedDict(
+    "DeleteBuildBatchOutputTypeDef",
+    {
+        "statusCode": str,
+        "buildsDeleted": List[str],
+        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteSourceCredentialsOutputTypeDef = TypedDict(
+    "DeleteSourceCredentialsOutputTypeDef",
+    {
+        "arn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeCodeCoveragesOutputTypeDef = TypedDict(
+    "DescribeCodeCoveragesOutputTypeDef",
+    {
+        "nextToken": str,
+        "codeCoverages": List["CodeCoverageTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeTestCasesOutputTypeDef = TypedDict(
+    "DescribeTestCasesOutputTypeDef",
+    {
+        "nextToken": str,
+        "testCases": List["TestCaseTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
 )
 
 EnvironmentImageTypeDef = TypedDict(
-    "EnvironmentImageTypeDef", {"name": str, "description": str, "versions": List[str]}, total=False
+    "EnvironmentImageTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "versions": List[str],
+    },
+    total=False,
 )
 
 EnvironmentLanguageTypeDef = TypedDict(
     "EnvironmentLanguageTypeDef",
-    {"language": LanguageType, "images": List["EnvironmentImageTypeDef"]},
+    {
+        "language": LanguageType,
+        "images": List["EnvironmentImageTypeDef"],
+    },
     total=False,
 )
 
 EnvironmentPlatformTypeDef = TypedDict(
     "EnvironmentPlatformTypeDef",
-    {"platform": PlatformType, "languages": List["EnvironmentLanguageTypeDef"]},
+    {
+        "platform": PlatformType,
+        "languages": List["EnvironmentLanguageTypeDef"],
+    },
     total=False,
 )
 
 _RequiredEnvironmentVariableTypeDef = TypedDict(
-    "_RequiredEnvironmentVariableTypeDef", {"name": str, "value": str}
+    "_RequiredEnvironmentVariableTypeDef",
+    {
+        "name": str,
+        "value": str,
+    },
 )
 _OptionalEnvironmentVariableTypeDef = TypedDict(
-    "_OptionalEnvironmentVariableTypeDef", {"type": EnvironmentVariableType}, total=False
+    "_OptionalEnvironmentVariableTypeDef",
+    {
+        "type": EnvironmentVariableType,
+    },
+    total=False,
 )
 
 
@@ -380,14 +551,158 @@ class EnvironmentVariableTypeDef(
 
 
 ExportedEnvironmentVariableTypeDef = TypedDict(
-    "ExportedEnvironmentVariableTypeDef", {"name": str, "value": str}, total=False
+    "ExportedEnvironmentVariableTypeDef",
+    {
+        "name": str,
+        "value": str,
+    },
+    total=False,
 )
 
-GitSubmodulesConfigTypeDef = TypedDict("GitSubmodulesConfigTypeDef", {"fetchSubmodules": bool})
+GetReportGroupTrendOutputTypeDef = TypedDict(
+    "GetReportGroupTrendOutputTypeDef",
+    {
+        "stats": "ReportGroupTrendStatsTypeDef",
+        "rawData": List["ReportWithRawDataTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetResourcePolicyOutputTypeDef = TypedDict(
+    "GetResourcePolicyOutputTypeDef",
+    {
+        "policy": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GitSubmodulesConfigTypeDef = TypedDict(
+    "GitSubmodulesConfigTypeDef",
+    {
+        "fetchSubmodules": bool,
+    },
+)
+
+ImportSourceCredentialsOutputTypeDef = TypedDict(
+    "ImportSourceCredentialsOutputTypeDef",
+    {
+        "arn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListBuildBatchesForProjectOutputTypeDef = TypedDict(
+    "ListBuildBatchesForProjectOutputTypeDef",
+    {
+        "ids": List[str],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListBuildBatchesOutputTypeDef = TypedDict(
+    "ListBuildBatchesOutputTypeDef",
+    {
+        "ids": List[str],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListBuildsForProjectOutputTypeDef = TypedDict(
+    "ListBuildsForProjectOutputTypeDef",
+    {
+        "ids": List[str],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListBuildsOutputTypeDef = TypedDict(
+    "ListBuildsOutputTypeDef",
+    {
+        "ids": List[str],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListCuratedEnvironmentImagesOutputTypeDef = TypedDict(
+    "ListCuratedEnvironmentImagesOutputTypeDef",
+    {
+        "platforms": List["EnvironmentPlatformTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListProjectsOutputTypeDef = TypedDict(
+    "ListProjectsOutputTypeDef",
+    {
+        "nextToken": str,
+        "projects": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListReportGroupsOutputTypeDef = TypedDict(
+    "ListReportGroupsOutputTypeDef",
+    {
+        "nextToken": str,
+        "reportGroups": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListReportsForReportGroupOutputTypeDef = TypedDict(
+    "ListReportsForReportGroupOutputTypeDef",
+    {
+        "nextToken": str,
+        "reports": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListReportsOutputTypeDef = TypedDict(
+    "ListReportsOutputTypeDef",
+    {
+        "nextToken": str,
+        "reports": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListSharedProjectsOutputTypeDef = TypedDict(
+    "ListSharedProjectsOutputTypeDef",
+    {
+        "nextToken": str,
+        "projects": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListSharedReportGroupsOutputTypeDef = TypedDict(
+    "ListSharedReportGroupsOutputTypeDef",
+    {
+        "nextToken": str,
+        "reportGroups": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListSourceCredentialsOutputTypeDef = TypedDict(
+    "ListSourceCredentialsOutputTypeDef",
+    {
+        "sourceCredentialsInfos": List["SourceCredentialsInfoTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
 LogsConfigTypeDef = TypedDict(
     "LogsConfigTypeDef",
-    {"cloudWatchLogs": "CloudWatchLogsConfigTypeDef", "s3Logs": "S3LogsConfigTypeDef"},
+    {
+        "cloudWatchLogs": "CloudWatchLogsConfigTypeDef",
+        "s3Logs": "S3LogsConfigTypeDef",
+    },
     total=False,
 )
 
@@ -407,15 +722,38 @@ LogsLocationTypeDef = TypedDict(
 )
 
 NetworkInterfaceTypeDef = TypedDict(
-    "NetworkInterfaceTypeDef", {"subnetId": str, "networkInterfaceId": str}, total=False
+    "NetworkInterfaceTypeDef",
+    {
+        "subnetId": str,
+        "networkInterfaceId": str,
+    },
+    total=False,
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
 )
 
 PhaseContextTypeDef = TypedDict(
-    "PhaseContextTypeDef", {"statusCode": str, "message": str}, total=False
+    "PhaseContextTypeDef",
+    {
+        "statusCode": str,
+        "message": str,
+    },
+    total=False,
 )
 
 _RequiredProjectArtifactsTypeDef = TypedDict(
-    "_RequiredProjectArtifactsTypeDef", {"type": ArtifactsType}
+    "_RequiredProjectArtifactsTypeDef",
+    {
+        "type": ArtifactsType,
+    },
 )
 _OptionalProjectArtifactsTypeDef = TypedDict(
     "_OptionalProjectArtifactsTypeDef",
@@ -439,7 +777,12 @@ class ProjectArtifactsTypeDef(_RequiredProjectArtifactsTypeDef, _OptionalProject
 
 
 ProjectBadgeTypeDef = TypedDict(
-    "ProjectBadgeTypeDef", {"badgeEnabled": bool, "badgeRequestUrl": str}, total=False
+    "ProjectBadgeTypeDef",
+    {
+        "badgeEnabled": bool,
+        "badgeRequestUrl": str,
+    },
+    total=False,
 )
 
 ProjectBuildBatchConfigTypeDef = TypedDict(
@@ -453,9 +796,19 @@ ProjectBuildBatchConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredProjectCacheTypeDef = TypedDict("_RequiredProjectCacheTypeDef", {"type": CacheType})
+_RequiredProjectCacheTypeDef = TypedDict(
+    "_RequiredProjectCacheTypeDef",
+    {
+        "type": CacheType,
+    },
+)
 _OptionalProjectCacheTypeDef = TypedDict(
-    "_OptionalProjectCacheTypeDef", {"location": str, "modes": List[CacheMode]}, total=False
+    "_OptionalProjectCacheTypeDef",
+    {
+        "location": str,
+        "modes": List[CacheMode],
+    },
+    total=False,
 )
 
 
@@ -465,7 +818,11 @@ class ProjectCacheTypeDef(_RequiredProjectCacheTypeDef, _OptionalProjectCacheTyp
 
 _RequiredProjectEnvironmentTypeDef = TypedDict(
     "_RequiredProjectEnvironmentTypeDef",
-    {"type": EnvironmentType, "image": str, "computeType": ComputeType},
+    {
+        "type": EnvironmentType,
+        "image": str,
+        "computeType": ComputeType,
+    },
 )
 _OptionalProjectEnvironmentTypeDef = TypedDict(
     "_OptionalProjectEnvironmentTypeDef",
@@ -489,7 +846,7 @@ class ProjectEnvironmentTypeDef(
 ProjectFileSystemLocationTypeDef = TypedDict(
     "ProjectFileSystemLocationTypeDef",
     {
-        "type": FileSystemType,
+        "type": Literal["EFS"],
         "location": str,
         "mountPoint": str,
         "identifier": str,
@@ -498,7 +855,12 @@ ProjectFileSystemLocationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredProjectSourceTypeDef = TypedDict("_RequiredProjectSourceTypeDef", {"type": SourceType})
+_RequiredProjectSourceTypeDef = TypedDict(
+    "_RequiredProjectSourceTypeDef",
+    {
+        "type": SourceType,
+    },
+)
 _OptionalProjectSourceTypeDef = TypedDict(
     "_OptionalProjectSourceTypeDef",
     {
@@ -521,7 +883,11 @@ class ProjectSourceTypeDef(_RequiredProjectSourceTypeDef, _OptionalProjectSource
 
 
 ProjectSourceVersionTypeDef = TypedDict(
-    "ProjectSourceVersionTypeDef", {"sourceIdentifier": str, "sourceVersion": str}
+    "ProjectSourceVersionTypeDef",
+    {
+        "sourceIdentifier": str,
+        "sourceVersion": str,
+    },
 )
 
 ProjectTypeDef = TypedDict(
@@ -556,18 +922,47 @@ ProjectTypeDef = TypedDict(
     total=False,
 )
 
+PutResourcePolicyOutputTypeDef = TypedDict(
+    "PutResourcePolicyOutputTypeDef",
+    {
+        "resourceArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 RegistryCredentialTypeDef = TypedDict(
-    "RegistryCredentialTypeDef", {"credential": str, "credentialProvider": CredentialProviderType}
+    "RegistryCredentialTypeDef",
+    {
+        "credential": str,
+        "credentialProvider": Literal["SECRETS_MANAGER"],
+    },
 )
 
 ReportExportConfigTypeDef = TypedDict(
     "ReportExportConfigTypeDef",
-    {"exportConfigType": ReportExportConfigType, "s3Destination": "S3ReportExportConfigTypeDef"},
+    {
+        "exportConfigType": ReportExportConfigType,
+        "s3Destination": "S3ReportExportConfigTypeDef",
+    },
+    total=False,
+)
+
+ReportFilterTypeDef = TypedDict(
+    "ReportFilterTypeDef",
+    {
+        "status": ReportStatusType,
+    },
     total=False,
 )
 
 ReportGroupTrendStatsTypeDef = TypedDict(
-    "ReportGroupTrendStatsTypeDef", {"average": str, "max": str, "min": str}, total=False
+    "ReportGroupTrendStatsTypeDef",
+    {
+        "average": str,
+        "max": str,
+        "min": str,
+    },
+    total=False,
 )
 
 ReportGroupTypeDef = TypedDict(
@@ -605,17 +1000,26 @@ ReportTypeDef = TypedDict(
 )
 
 ReportWithRawDataTypeDef = TypedDict(
-    "ReportWithRawDataTypeDef", {"reportArn": str, "data": str}, total=False
+    "ReportWithRawDataTypeDef",
+    {
+        "reportArn": str,
+        "data": str,
+    },
+    total=False,
 )
 
 ResolvedArtifactTypeDef = TypedDict(
     "ResolvedArtifactTypeDef",
-    {"type": ArtifactsType, "location": str, "identifier": str},
+    {
+        "type": ArtifactsType,
+        "location": str,
+        "identifier": str,
+    },
     total=False,
 )
 
-ResponseMetadata = TypedDict(
-    "ResponseMetadata",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
         "RequestId": str,
         "HostId": str,
@@ -625,12 +1029,35 @@ ResponseMetadata = TypedDict(
     },
 )
 
+RetryBuildBatchOutputTypeDef = TypedDict(
+    "RetryBuildBatchOutputTypeDef",
+    {
+        "buildBatch": "BuildBatchTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+RetryBuildOutputTypeDef = TypedDict(
+    "RetryBuildOutputTypeDef",
+    {
+        "build": "BuildTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredS3LogsConfigTypeDef = TypedDict(
-    "_RequiredS3LogsConfigTypeDef", {"status": LogsConfigStatusType}
+    "_RequiredS3LogsConfigTypeDef",
+    {
+        "status": LogsConfigStatusType,
+    },
 )
 _OptionalS3LogsConfigTypeDef = TypedDict(
     "_OptionalS3LogsConfigTypeDef",
-    {"location": str, "encryptionDisabled": bool, "bucketOwnerAccess": BucketOwnerAccess},
+    {
+        "location": str,
+        "encryptionDisabled": bool,
+        "bucketOwnerAccess": BucketOwnerAccess,
+    },
     total=False,
 )
 
@@ -652,8 +1079,19 @@ S3ReportExportConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": SourceAuthType})
-_OptionalSourceAuthTypeDef = TypedDict("_OptionalSourceAuthTypeDef", {"resource": str}, total=False)
+_RequiredSourceAuthTypeDef = TypedDict(
+    "_RequiredSourceAuthTypeDef",
+    {
+        "type": Literal["OAUTH"],
+    },
+)
+_OptionalSourceAuthTypeDef = TypedDict(
+    "_OptionalSourceAuthTypeDef",
+    {
+        "resource": str,
+    },
+    total=False,
+)
 
 
 class SourceAuthTypeDef(_RequiredSourceAuthTypeDef, _OptionalSourceAuthTypeDef):
@@ -662,11 +1100,63 @@ class SourceAuthTypeDef(_RequiredSourceAuthTypeDef, _OptionalSourceAuthTypeDef):
 
 SourceCredentialsInfoTypeDef = TypedDict(
     "SourceCredentialsInfoTypeDef",
-    {"arn": str, "serverType": ServerType, "authType": AuthType},
+    {
+        "arn": str,
+        "serverType": ServerType,
+        "authType": AuthType,
+    },
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
+StartBuildBatchOutputTypeDef = TypedDict(
+    "StartBuildBatchOutputTypeDef",
+    {
+        "buildBatch": "BuildBatchTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StartBuildOutputTypeDef = TypedDict(
+    "StartBuildOutputTypeDef",
+    {
+        "build": "BuildTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopBuildBatchOutputTypeDef = TypedDict(
+    "StopBuildBatchOutputTypeDef",
+    {
+        "buildBatch": "BuildBatchTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopBuildOutputTypeDef = TypedDict(
+    "StopBuildOutputTypeDef",
+    {
+        "build": "BuildTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TagTypeDef = TypedDict(
+    "TagTypeDef",
+    {
+        "key": str,
+        "value": str,
+    },
+    total=False,
+)
+
+TestCaseFilterTypeDef = TypedDict(
+    "TestCaseFilterTypeDef",
+    {
+        "status": str,
+        "keyword": str,
+    },
+    total=False,
+)
 
 TestCaseTypeDef = TypedDict(
     "TestCaseTypeDef",
@@ -685,20 +1175,60 @@ TestCaseTypeDef = TypedDict(
 
 TestReportSummaryTypeDef = TypedDict(
     "TestReportSummaryTypeDef",
-    {"total": int, "statusCounts": Dict[str, int], "durationInNanoSeconds": int},
+    {
+        "total": int,
+        "statusCounts": Dict[str, int],
+        "durationInNanoSeconds": int,
+    },
+)
+
+UpdateProjectOutputTypeDef = TypedDict(
+    "UpdateProjectOutputTypeDef",
+    {
+        "project": "ProjectTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateReportGroupOutputTypeDef = TypedDict(
+    "UpdateReportGroupOutputTypeDef",
+    {
+        "reportGroup": "ReportGroupTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateWebhookOutputTypeDef = TypedDict(
+    "UpdateWebhookOutputTypeDef",
+    {
+        "webhook": "WebhookTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
 )
 
 VpcConfigTypeDef = TypedDict(
     "VpcConfigTypeDef",
-    {"vpcId": str, "subnets": List[str], "securityGroupIds": List[str]},
+    {
+        "vpcId": str,
+        "subnets": List[str],
+        "securityGroupIds": List[str],
+    },
     total=False,
 )
 
 _RequiredWebhookFilterTypeDef = TypedDict(
-    "_RequiredWebhookFilterTypeDef", {"type": WebhookFilterType, "pattern": str}
+    "_RequiredWebhookFilterTypeDef",
+    {
+        "type": WebhookFilterType,
+        "pattern": str,
+    },
 )
 _OptionalWebhookFilterTypeDef = TypedDict(
-    "_OptionalWebhookFilterTypeDef", {"excludeMatchedPattern": bool}, total=False
+    "_OptionalWebhookFilterTypeDef",
+    {
+        "excludeMatchedPattern": bool,
+    },
+    total=False,
 )
 
 
@@ -719,287 +1249,3 @@ WebhookTypeDef = TypedDict(
     },
     total=False,
 )
-
-BatchDeleteBuildsOutputTypeDef = TypedDict(
-    "BatchDeleteBuildsOutputTypeDef",
-    {
-        "buildsDeleted": List[str],
-        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BatchGetBuildBatchesOutputTypeDef = TypedDict(
-    "BatchGetBuildBatchesOutputTypeDef",
-    {
-        "buildBatches": List["BuildBatchTypeDef"],
-        "buildBatchesNotFound": List[str],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BatchGetBuildsOutputTypeDef = TypedDict(
-    "BatchGetBuildsOutputTypeDef",
-    {
-        "builds": List["BuildTypeDef"],
-        "buildsNotFound": List[str],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BatchGetProjectsOutputTypeDef = TypedDict(
-    "BatchGetProjectsOutputTypeDef",
-    {
-        "projects": List["ProjectTypeDef"],
-        "projectsNotFound": List[str],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BatchGetReportGroupsOutputTypeDef = TypedDict(
-    "BatchGetReportGroupsOutputTypeDef",
-    {
-        "reportGroups": List["ReportGroupTypeDef"],
-        "reportGroupsNotFound": List[str],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BatchGetReportsOutputTypeDef = TypedDict(
-    "BatchGetReportsOutputTypeDef",
-    {
-        "reports": List["ReportTypeDef"],
-        "reportsNotFound": List[str],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-BuildBatchFilterTypeDef = TypedDict("BuildBatchFilterTypeDef", {"status": StatusType}, total=False)
-
-CreateProjectOutputTypeDef = TypedDict(
-    "CreateProjectOutputTypeDef",
-    {"project": "ProjectTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-CreateReportGroupOutputTypeDef = TypedDict(
-    "CreateReportGroupOutputTypeDef",
-    {"reportGroup": "ReportGroupTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-CreateWebhookOutputTypeDef = TypedDict(
-    "CreateWebhookOutputTypeDef",
-    {"webhook": "WebhookTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-DeleteBuildBatchOutputTypeDef = TypedDict(
-    "DeleteBuildBatchOutputTypeDef",
-    {
-        "statusCode": str,
-        "buildsDeleted": List[str],
-        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-DeleteSourceCredentialsOutputTypeDef = TypedDict(
-    "DeleteSourceCredentialsOutputTypeDef",
-    {"arn": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-DescribeCodeCoveragesOutputTypeDef = TypedDict(
-    "DescribeCodeCoveragesOutputTypeDef",
-    {
-        "nextToken": str,
-        "codeCoverages": List["CodeCoverageTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-DescribeTestCasesOutputTypeDef = TypedDict(
-    "DescribeTestCasesOutputTypeDef",
-    {
-        "nextToken": str,
-        "testCases": List["TestCaseTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-GetReportGroupTrendOutputTypeDef = TypedDict(
-    "GetReportGroupTrendOutputTypeDef",
-    {
-        "stats": "ReportGroupTrendStatsTypeDef",
-        "rawData": List["ReportWithRawDataTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-GetResourcePolicyOutputTypeDef = TypedDict(
-    "GetResourcePolicyOutputTypeDef",
-    {"policy": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ImportSourceCredentialsOutputTypeDef = TypedDict(
-    "ImportSourceCredentialsOutputTypeDef",
-    {"arn": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListBuildBatchesForProjectOutputTypeDef = TypedDict(
-    "ListBuildBatchesForProjectOutputTypeDef",
-    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListBuildBatchesOutputTypeDef = TypedDict(
-    "ListBuildBatchesOutputTypeDef",
-    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListBuildsForProjectOutputTypeDef = TypedDict(
-    "ListBuildsForProjectOutputTypeDef",
-    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListBuildsOutputTypeDef = TypedDict(
-    "ListBuildsOutputTypeDef",
-    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListCuratedEnvironmentImagesOutputTypeDef = TypedDict(
-    "ListCuratedEnvironmentImagesOutputTypeDef",
-    {"platforms": List["EnvironmentPlatformTypeDef"], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListProjectsOutputTypeDef = TypedDict(
-    "ListProjectsOutputTypeDef",
-    {"nextToken": str, "projects": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListReportGroupsOutputTypeDef = TypedDict(
-    "ListReportGroupsOutputTypeDef",
-    {"nextToken": str, "reportGroups": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListReportsForReportGroupOutputTypeDef = TypedDict(
-    "ListReportsForReportGroupOutputTypeDef",
-    {"nextToken": str, "reports": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListReportsOutputTypeDef = TypedDict(
-    "ListReportsOutputTypeDef",
-    {"nextToken": str, "reports": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListSharedProjectsOutputTypeDef = TypedDict(
-    "ListSharedProjectsOutputTypeDef",
-    {"nextToken": str, "projects": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListSharedReportGroupsOutputTypeDef = TypedDict(
-    "ListSharedReportGroupsOutputTypeDef",
-    {"nextToken": str, "reportGroups": List[str], "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ListSourceCredentialsOutputTypeDef = TypedDict(
-    "ListSourceCredentialsOutputTypeDef",
-    {
-        "sourceCredentialsInfos": List["SourceCredentialsInfoTypeDef"],
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
-)
-
-PutResourcePolicyOutputTypeDef = TypedDict(
-    "PutResourcePolicyOutputTypeDef",
-    {"resourceArn": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-ReportFilterTypeDef = TypedDict("ReportFilterTypeDef", {"status": ReportStatusType}, total=False)
-
-RetryBuildBatchOutputTypeDef = TypedDict(
-    "RetryBuildBatchOutputTypeDef",
-    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-RetryBuildOutputTypeDef = TypedDict(
-    "RetryBuildOutputTypeDef",
-    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-StartBuildBatchOutputTypeDef = TypedDict(
-    "StartBuildBatchOutputTypeDef",
-    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-StartBuildOutputTypeDef = TypedDict(
-    "StartBuildOutputTypeDef",
-    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-StopBuildBatchOutputTypeDef = TypedDict(
-    "StopBuildBatchOutputTypeDef",
-    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-StopBuildOutputTypeDef = TypedDict(
-    "StopBuildOutputTypeDef",
-    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-TestCaseFilterTypeDef = TypedDict(
-    "TestCaseFilterTypeDef", {"status": str, "keyword": str}, total=False
-)
-
-UpdateProjectOutputTypeDef = TypedDict(
-    "UpdateProjectOutputTypeDef",
-    {"project": "ProjectTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-UpdateReportGroupOutputTypeDef = TypedDict(
-    "UpdateReportGroupOutputTypeDef",
-    {"reportGroup": "ReportGroupTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-UpdateWebhookOutputTypeDef = TypedDict(
-    "UpdateWebhookOutputTypeDef",
-    {"webhook": "WebhookTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
